==> ipyroute-0.0.11.tar.gz: ipyroute-0.0.11/ipyroute/rule.py <==
""" Lookup rules """
import re
from ipyroute import base

class Rule(base.Base):
    regex = re.compile(r'(?P<pref>\d+):\s+'
                       r'(from (?P<fromprefix>\w+)\s+)?'
                       r'(to (?P<toprefix>\w+)\s+)?'
                       r'(fwmark (?P<fwmark>\w+)\s+)?'
                       r'(lookup (?P<lookup>\w+))?')

    casts = dict(pref=int,
                 fwmark=lambda x: int(x, 16),
                 fromprefix=base.IPNetwork,
                 toprefix=base.IPNetwork)
    _order = ('from', 'fwmark', 'lookup', 'pref')

    @classmethod
    def _get(cls, *args):
        for line in cls.cmd.show(*args):
            yield line

    @classmethod
    def add(cls, fromprefix, **kwargs):
        """ Add command for address. """
        kwargs['from'] = cls._allprefix if fromprefix == 'any' else str(fromprefix)
        return cls.shwrap(cls.cmd.add, cls._order)(**kwargs)

    def delete(self):
        """ Delete command for rule. """
        kwargs = dict([(k.replace('prefix', ''), str(v))
                      for (k, v) in self.__dict__.items() if v is not None])
        return self.shwrap(getattr(self.cmd, 'del'), self._order)(**kwargs)

    @classmethod
    def construct(cls, result, _, *args):
        fromprefix = result.get('fromprefix')
        if fromprefix == 'all':
            result['fromprefix'] = cls._allprefix
        return cls(**result)

class Rule4(Rule):
    _allprefix = "0.0.0.0/0"

    @base.classproperty
    def cmd(cls, *args):
        """ Rules are a pain because we have to manage both v4 and v6 transparently. """
        return base.IPR.ipv4.rule

class Rule6(Rule):
    _allprefix = "::/0"

    @base.classproperty
    def cmd(cls, *args):
        """ Rules are a pain because we have to manage both v4 and v6 transparently. """
        return base.IPR.ipv6.rule

==> ipyroute-0.0.12.tar.gz: ipyroute-0.0.12/ipyroute/rule.py <==
""" Lookup rules """
import re
from ipyroute import base

class Rule(base.Base):
    regex = re.compile(r'(?P<pref>\d+):\s+'
                       r'(from (?P<fromprefix>\w+)\s+)?'
                       r'(to (?P<toprefix>\w+)\s+)?'
                       r'(fwmark (?P<fwmark>\w+)\s+)?'
                       r'(lookup (?P<lookup>\w+))?')

    casts = dict(pref=int,
                 fwmark=lambda x: int(x, 16) if 'x' in x else int(x),
                 fromprefix=base.IPNetwork,
                 toprefix=base.IPNetwork)
    _order = ('from', 'fwmark', 'lookup', 'pref')

    @classmethod
    def _get(cls, *args):
        for line in cls.cmd.show(*args):
            yield line

    @classmethod
    def add(cls, fromprefix, **kwargs):
        """ Add command for address. """
        kwargs['from'] = cls.anyaddr if fromprefix == 'any' else str(fromprefix)
        return cls.shwrap(cls.cmd.add, cls._order)(**kwargs)

    def delete(self):
        """ Delete command for rule. """
        kwargs = dict([(k.replace('prefix', ''), str(v))
                      for (k, v) in self.__dict__.items() if v is not None])
        return self.shwrap(getattr(self.cmd, 'del'), self._order)(**kwargs)

    @classmethod
    def construct(cls, result, _, *args):
        fromprefix = result.get('fromprefix')
        if fromprefix == 'all':
            result['fromprefix'] = cls.anyaddr
        return cls(**result)

    def __hash__(self):
        """ Needed for constructing rule sets. """
        return self.pref

class Rule4(Rule):
    anyaddr = "0.0.0.0/0"

    @base.classproperty
    def cmd(cls, *args):
        """ Rules are a pain because we have to manage both v4 and v6 transparently. """
        return base.IPR.ipv4.rule

class Rule6(Rule):
    anyaddr = "::/0"

    @base.classproperty
    def cmd(cls, *args):
        """ Rules are a pain because we have to manage both v4 and v6 transparently. """
        return base.IPR.ipv6.rule
